@@ -30,6 +30,8 @@
 */
 #include "lasreader_dtm.hpp"
 
+#include "lasvlrpayload.hpp"
+
 // used to map GeoTIFF codes to GCTP codes
 
 static const unsigned short PCS_NAD83_Alabama_East = 26929;
@@ -1159,6 +1161,25 @@ BOOL LASreaderDTM::open(const CHAR* file_name)
     header.max_z = 0;
   }
 
+  // add the VLR for Raster LAZ 
+
+  LASvlrRasterLAZ vlrRasterLAZ;
+  vlrRasterLAZ.nbands = 1;
+  vlrRasterLAZ.nbits = 32;
+  vlrRasterLAZ.ncols = ncols;
+  vlrRasterLAZ.nrows = nrows;
+  vlrRasterLAZ.reserved1 = 0;
+  vlrRasterLAZ.reserved2 = 0;
+  vlrRasterLAZ.stepx = xdim;
+  vlrRasterLAZ.stepx_y = 0.0;
+  vlrRasterLAZ.stepy = ydim;
+  vlrRasterLAZ.stepy_x = 0.0;
+  vlrRasterLAZ.llx = ll_x;
+  vlrRasterLAZ.lly = ll_y;
+  vlrRasterLAZ.sigmaxy = 0.0;
+
+  header.add_vlr("Raster LAZ", 7113, (U16)vlrRasterLAZ.get_payload_size(), vlrRasterLAZ.get_payload(), FALSE, "by LAStools of rapidlasso GmbH", FALSE);
+
   // reopen
 
   return reopen(file_name);
@@ -1279,9 +1300,18 @@ BOOL LASreaderDTM::read_point_default()
 
     if (elevation != nodata)
     {
-      point.set_x(ll_x + col * xdim);
-      point.set_y(ll_y + row * ydim);
-      point.set_z(elevation);
+      if (!point.set_x(ll_x + col * xdim))
+      {
+        overflow_I32_x++;
+      }
+      if (!point.set_y(ll_y + row * ydim))
+      {
+        overflow_I32_y++;
+      }
+      if (!point.set_z(elevation))
+      {
+        overflow_I32_z++;
+      }
       p_count++;
       row++;
       return TRUE;
@@ -1301,6 +1331,33 @@ ByteStreamIn* LASreaderDTM::get_stream() const
 
 void LASreaderDTM::close(BOOL close_stream)
 {
+  if (overflow_I32_x)
+  {
+#ifdef _WIN32
+    REprintf( "WARNING: total of %I64d integer overflows in x\n", overflow_I32_x);
+#else
+    REprintf( "WARNING: total of %lld integer overflows in x\n", overflow_I32_x);
+#endif
+    overflow_I32_x = 0;
+  }
+  if (overflow_I32_y)
+  {
+#ifdef _WIN32
+    REprintf( "WARNING: total of %I64d integer overflows in y\n", overflow_I32_y);
+#else
+    REprintf( "WARNING: total of %lld integer overflows in y\n", overflow_I32_y);
+#endif
+    overflow_I32_y = 0;
+  }
+  if (overflow_I32_z)
+  {
+#ifdef _WIN32
+    REprintf( "WARNING: total of %I64d integer overflows in z\n", overflow_I32_z);
+#else
+    REprintf( "WARNING: total of %lld integer overflows in z\n", overflow_I32_z);
+#endif
+    overflow_I32_z = 0;
+  }
   if (file)
   {
     fclose(file);
@@ -1368,6 +1425,9 @@ void LASreaderDTM::clean()
   ll_y = 0.0;
   xdim = 0;
   ydim = 0;
+  overflow_I32_x = 0;
+  overflow_I32_y = 0;
+  overflow_I32_z = 0;
 }
 
 LASreaderDTM::LASreaderDTM()
@@ -1447,12 +1507,12 @@ void LASreaderDTM::populate_bounding_box()
 {
   // compute quantized and then unquantized bounding box
 
-  F64 dequant_min_x = header.get_x(header.get_X(header.min_x));
-  F64 dequant_max_x = header.get_x(header.get_X(header.max_x));
-  F64 dequant_min_y = header.get_y(header.get_Y(header.min_y));
-  F64 dequant_max_y = header.get_y(header.get_Y(header.max_y));
-  F64 dequant_min_z = header.get_z(header.get_Z(header.min_z));
-  F64 dequant_max_z = header.get_z(header.get_Z(header.max_z));
+  F64 dequant_min_x = header.get_x((I32)(header.get_X(header.min_x)));
+  F64 dequant_max_x = header.get_x((I32)(header.get_X(header.max_x)));
+  F64 dequant_min_y = header.get_y((I32)(header.get_Y(header.min_y)));
+  F64 dequant_max_y = header.get_y((I32)(header.get_Y(header.max_y)));
+  F64 dequant_min_z = header.get_z((I32)(header.get_Z(header.min_z)));
+  F64 dequant_max_z = header.get_z((I32)(header.get_Z(header.max_z)));
 
   // make sure there is not sign flip
 
